import React, { useState, useEffect, useMemo, useRef } from 'react';
import DrawerPro from '@/components/DrawerPro';
import AutoTable from '@/components/AutoTable';
import PremButton from '@/components/PremButton';
import useKeepAlive from "@/components/useKeepAlive";
import getcolumns from "./columns";
import { useRequest } from 'ahooks';
import { doFetch } from '@/utils/doFetch';
import {message} from "antd";
function User() {
    let actionRef = useRef();
    const [drawer, setdrawer] = useState({
        open: false,
    });
    const { run, loading, runAsync } = useRequest(doFetch, {
        manual: true,
        onSuccess: (res, params) => {
            if (res?.code == '0000') {
                reload();
            }
        },
    });
    const columns = useMemo(() => {
        let defcolumn = getcolumns(setdrawer);
        return defcolumn.concat({
            title: "操作",
            valueType: "option",
            width: 80,
            render: (text, row, _, action) => rightExtra(text, row, _, action),
        });
    }, []);
    const rightExtra = (text, row, _, action) => {
        return [
            <PremButton
                key='reset'
                pop={{
                    title: "是否重置密码?",
                    okText: "确认",
                    cancelText: "取消",
                    onConfirm: async () => {
                        let res = await runAsync({
                            url: "/ta_wms_auth/sysUser/restPassword",
                            params: { id: row.id },
                        });
                        if(res.code=='0000'){
                            message.success('重置密码成功！')
                        }
                    },
                }}
                btn={{
                    size: "small",
                    danger: true
                }}
            >
                重置密码
            </PremButton>,
            <PremButton
                key="edit"
                btn={{
                    type: "primary",
                    size: "small",
                    onClick: () => {
                        setdrawer(s => {
                            return {
                                ...s,
                                open: true,
                                title:'修改用户',
                                val: 'edit',
                                item: row,
                                detailpath:'/ta_wms_auth/sysUser/query/detail'
                            }
                        })
                    },
                }}
            >
                修改
            </PremButton>,
            <PremButton
                key='delete'
                pop={{
                    title: "是否删除该用户?",
                    okText: "确认",
                    cancelText: "取消",
                    onConfirm: async () => {
                        await runAsync({
                            url: "/ta_wms_auth/sysUser/deleteById",
                            params: { id: row.id },
                        });
                    },
                }}
                btn={{
                    size: "small",
                    danger: true
                }}
            >
                删除
            </PremButton>
        ];
    };
    function reload() {
        actionRef?.current?.reload();
        setdrawer((s) => ({
            ...s,
            open: false,
        }));
    }
    return <div>
        <AutoTable
            pagetitle='用户管理'
            columns={columns}
            path='/ta_wms_auth/sysUser/query/page'
            actionRef={actionRef}
            pageextra='add'
            addconfig={{
                // access: 'sysDepartment_save',
                name: '新增',
                btn: {
                    type: 'primary',
                    onClick: () => {
                        setdrawer((s) => ({
                            ...s,
                            open: true,
                            title: '新增',
                            val: 'add',
                            item: {},
                            detailpath:''
                        }));
                    },
                },
            }}
        />
        <DrawerPro
            {...drawer}
            fields={columns}
            detailpath={drawer.detailpath}
            params={{id:drawer?.item?.id}}
            placement="right"
            onClose={() => {
                setdrawer((s) => ({
                    ...s,
                    open: false,
                }));
            }}
            onFinish={async (vals) => {
                let newfields = JSON.parse(JSON.stringify(vals));
                await runAsync({
                    url: "/ta_wms_auth/sysUser/save",
                    params: { ...newfields, id: drawer?.val === 'edit' ? drawer?.item?.id : '' }
                });
            }}
            width='60%'
        />
    </div>;
}

export default useKeepAlive(User);